<?php

namespace Drupal\group_foldershare\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Url;

/**
 * Defines the GroupFoldershare entity.
 *
 * @ingroup group_foldershare
 *
 * @ContentEntityType(
 *   id = "group_foldershare",
 *   label          = @Translation("Group Foldershare"),
 *   label_singular = @Translation("Group Foldershare"),
 *   label_plural   = @Translation("Group Foldershares"),
 *   label_count    = @PluralTranslation(
 *     singular     = "@count Group Foldershare",
 *     plural       = "@count Group Foldershares"
 *   ),
 *   base_table = "group_foldershare",
 *   entity_keys = {
 *     "id"   = "id",
 *     "uuid" = "uuid",
 *   },
 *   handlers = {
 *     "views_data" = "Drupal\views\EntityViewsData",
 *   },
 * )
 */
class GroupFoldershare extends ContentEntityBase implements ContentEntityInterface
{

    /**
     * @inheritdoc
     */
    public static function baseFieldDefinitions(EntityTypeInterface $entity_type)
    {
        $fields = parent::baseFieldDefinitions($entity_type);

        $fields['foldershare_id'] = BaseFieldDefinition::create('entity_reference')
            ->setLabel(t('Foldershare id'))
            ->setDescription(t('The foldershare id for this GroupFoldershare.'))
            ->setSetting('target_type', 'foldershare')
            ->setSetting('handler', 'default');

        $fields['group_id'] = BaseFieldDefinition::create('entity_reference')
            ->setLabel(t('Group id'))
            ->setDescription(t('The group id for this GroupFoldershare.'))
            ->setSetting('target_type', 'group')
            ->setSetting('handler', 'default');

        $fields['menu_link_content_id'] = BaseFieldDefinition::create('entity_reference')
            ->setLabel(t('Menu link content id'))
            ->setDescription(t('The menu link content id for this GroupFoldershare.'))
            ->setSetting('target_type', 'menu_link_content')
            ->setRequired(FALSE)
            ->setSetting('handler', 'default');

        return $fields;
    }

    /**
     * Getter for foldershare_id
     * @return mixed
     */
    public function getFoldershareId()
    {
        return $this->foldershare_id[0]->target_id;
    }

    /**
     * Setter for foldershare_id
     * @param $foldershare_id
     */
    public function setFoldershareId($foldershare_id)
    {
        $this->set("foldershare_id", $foldershare_id);
    }

    /**
     * Getter for menu_link_content_id
     * @return mixed
     */
    public function getMenuLinkContentId()
    {
        return $this->menu_link_content_id[0]->target_id;
    }

    /**
     * Setter for menu_link_content_id
     * @param $menu_link_content_id
     */
    public function setMenuLinkContentId($menu_link_content_id)
    {
        $this->set("menu_link_content_id", $menu_link_content_id);
    }

    /**
     * Getter for group_id
     * @return mixed
     */
    public function getGroupId()
    {
        return $this->group_id[0]->target_id;
    }

    /**
     * Setter for group_id
     * @param $group_id
     */
    public function setGroupId($group_id)
    {
        $this->set("group_id", $group_id);
    }
}
