<?php
namespace Drupal\group_foldershare\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Entity\User;

class SettingsForm extends ConfigFormBase {

    /**
     * Config settings.
     *
     * @var string
     */
    const SETTINGS = 'group_foldershare.settings';

    /**
     * {@inheritdoc}
     */
    public function getFormId() {
        return 'group_foldershare_admin_settings';
    }

    /**
     * {@inheritdoc}
     */
    protected function getEditableConfigNames() {
        return [
            static::SETTINGS,
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state) {
        $config = $this->config(static::SETTINGS);

        $default_autocreatedFolderOwner = $config->get("autocreatedFolderOwner");
        $default_autocreatedFolderOwner_selectedUser = $config->get("autocreatedFolderOwner_selectedUser");

        $default_autocreatedFolderOwner_selectedUser = User::load($default_autocreatedFolderOwner_selectedUser);

        $form["autocreatedFolderOwner"] = [
            '#type' => 'radios',
            '#title' => "Owner for auto-created Group Foldershare folders",
            '#help' => "The selected user will be the owner for auto-created group Foldershare folders.",
            '#default_value' => $default_autocreatedFolderOwner,
            '#options' => array(
                'site_admin' => $this->t('Site administrator'),
                'group_owner' => $this->t("Group's owner"),
                'select_user' => $this->t("Select user"),
            ),
            '#attributes' => [
                 'id' => 'field_autocreatedFolderOwner',
            ],
        ];

        $form["autocreatedFolderOwner_select_user"] = [
            '#title' => ('Select User'),
            '#type' => 'entity_autocomplete',
            '#target_type' => 'user',
            '#required' => TRUE,
            '#default_value' => $default_autocreatedFolderOwner_selectedUser,
            '#selection_settings' => [
                'include_anonymous' => FALSE,
            ],
            '#attributes' => [
                'id' => 'autocreatedFolderOwner_select_user',
            ],
            '#states' => [
                'visible' => [
                    ':input[id="field_autocreatedFolderOwner"]' => ['value' => 'select_user'],
                ],
            ],
        ];

        return parent::buildForm($form, $form_state);
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state) {

        $autocreatedFolderOwner = $form_state->getValue("autocreatedFolderOwner");
        $autocreatedFolderOwner_select_user = $form_state->getValue("autocreatedFolderOwner_select_user");

        $this->configFactory->getEditable(static::SETTINGS)
            ->set("autocreatedFolderOwner", $autocreatedFolderOwner)
            ->set("autocreatedFolderOwner_selectedUser", $autocreatedFolderOwner_select_user)
            ->save();

        parent::submitForm($form, $form_state);
    }
}

