<?php
namespace Drupal\group_foldershare;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleUninstallValidatorInterface;

/**
 * Prevents this module from being uninstalled whilst any group type has the group_foldershare plugin enabled.
 */
class GroupFoldershareUninstallValidator implements ModuleUninstallValidatorInterface {

    /**
     * The entity type manager.
     *
     * @var \Drupal\Core\Entity\EntityTypeManagerInterface
     */
    protected $entityTypeManager;

    /**
     * Constructs a new GroupFoldershareUninstallValidator.
     *
     * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
     *   The entity type manager.
     */
    public function __construct(EntityTypeManagerInterface $entity_type_manager) {
        $this->entityTypeManager = $entity_type_manager;
    }

    /**
     * {@inheritdoc}
     */
    public function validate($module) {
        $reasons = [];
        if ($module == 'group_foldershare') {
            $group_types = $this->getGroupTypesEnabledWithFoldershare();
            if ($group_types) {
                $installed_group_types = implode(', ', $group_types);
                $reasons[] = t("The 'Group Foldershare' group content plugin is still installed in the following group types: $installed_group_types");
            }
        }
        return $reasons;
    }

    /**
     * Get all the group types that have enabled Foldershare as an allowed content type.
     * @return array
     */
    protected function getGroupTypesEnabledWithFoldershare() {
        /* @var \Drupal\group\Entity\Storage\GroupRelationshipTypeStorageInterface $storage */
        $storage = $this->entityTypeManager
            ->getStorage('group_relationship_type');
        $group_content_types_with_foldershare = $storage->loadByPluginId("group_foldershare");
        $group_types = array();

        foreach(array_values($group_content_types_with_foldershare) as $group_content_type) {
            $group_type = $group_content_type->getGroupType();
            $group_url = $group_type->toUrl()->toString();
            $group_label = $group_type->label();

            $group_types[] = "<a href='$group_url' target='_blank'>$group_label</a>";
        }
        return $group_types;
    }

}